from setuptools import setup

setup(name='gardenbox',
      version='0.2',
      description='Shared package for GardenBox usage',
      url='https://gitlab.imerir.com/anatoli/garden-box',
      author='Imerir',
      author_email='anthony.natoli@imerir.com',
      license='MIT',
      packages=['gardenbox'],
      zip_safe=False)

